from setuptools import setup, find_packages

setup(
    name='openknowit_kalm_common',
    version='1.0.1',
    long_description=open("README.md").read(),
    long_description_content_type="text/markdown",
    packages=find_packages(),
    install_requires=[]
)
